@@ -3,6 +3,7 @@ import os
 from enum import Enum
 from io import BytesIO
 import json
+import warnings
 from typing import IO, Any, Dict, List, Optional, Union
 
 import arrow
@@ -194,11 +195,11 @@ class Client:
 
         event_id: The id of the event to delete.
         """
-        request = requests.delete(
+        response = requests.delete(
             self.__url__(f"/beta/device-events/{event_id}"),
             headers=self.__headers,
         )
-        request.raise_for_status()
+        json_or_raise(response)
 
     def get_events(
         self,
@@ -221,7 +222,7 @@ class Client:
             Either device_id or device_name is required.
         sort_by: Optionally sort records by this field name (e.g. "device_id").
         sort_order: Optionally specify the sort order, either "asc" or "desc".
-        limit: Optionally limit the number of records return.
+        limit: Optionally limit the number of records returned.
         offset: Optionally offset the results by this many records.
         start: Optionally exclude records before this time.
         end: Optionally exclude records after this time.
@@ -246,7 +247,7 @@ class Client:
         response = requests.get(
             self.__url__("/beta/device-events"),
             headers=self.__headers,
-            params={k: v for k, v in params.items() if v},
+            params={k: v for k, v in params.items() if v is not None},
         )
 
         json = json_or_raise(response)
@@ -332,19 +333,19 @@ class Client:
         link_response = requests.post(
             self.__url__("/v1/data/stream"),
             headers=self.__headers,
-            json={k: v for k, v in params.items() if v},
+            json={k: v for k, v in params.items() if v is not None},
         )
 
         json = json_or_raise(link_response)
 
         link = json["link"]
         response = requests.get(link, stream=True)
-        data = bytes()
+        data = BytesIO()
         for chunk in response.iter_content(chunk_size=32 * 1024):
-            data += chunk
+            data.write(chunk)
             if callback:
-                callback(progress=len(data))
-        return data
+                callback(progress=data.tell())
+        return data.getvalue()
 
     def get_coverage(
         self,
@@ -371,7 +372,7 @@ class Client:
         response = requests.get(
             self.__url__("/v1/data/coverage"),
             headers=self.__headers,
-            params={k: v for k, v in params.items() if v},
+            params={k: v for k, v in params.items() if v is not None},
         )
         json = json_or_raise(response)
 
@@ -400,7 +401,6 @@ class Client:
         return {
             "id": device["id"],
             "name": device["name"],
-            "serial_number": device["serialNumber"],
             "created_at": arrow.get(device["createdAt"]).datetime,
             "updated_at": arrow.get(device["updatedAt"]).datetime,
         }
@@ -420,7 +420,6 @@ class Client:
             {
                 "id": d["id"],
                 "name": d["name"],
-                "serial_number": d["serialNumber"],
                 "created_at": arrow.get(d["createdAt"]).datetime,
                 "updated_at": arrow.get(d["updatedAt"]).datetime,
             }
@@ -430,28 +429,27 @@ class Client:
     def create_device(
         self,
         name: str,
-        serial_number: str,
+        serial_number: Optional[str] = None,
     ):
         """
         Creates a new device.
 
-        device_id: The name of the devicee.
-        serial_number: The unique serial number of the devicde.
+        name: The name of the devicee.
+        serial_number: DEPRECATED: a serial number for the device. This argument has no effect.
         """
-        request = requests.post(
-            self.__url__("/v1/devices"),
-            headers=self.__headers,
-            json={
-                "name": name,
-                "serialNumber": serial_number,
-            },
+        if serial_number is not None:
+            warnings.warn(
+                "serial number argument is deprecated and will be removed in the next release"
+            )
+        response = requests.post(
+            self.__url__("/v1/devices"), headers=self.__headers, json={"name": name}
         )
-        request.raise_for_status()
-        device = request.json()
+
+        device = json_or_raise(response)
+
         return {
             "id": device["id"],
             "name": device["name"],
-            "serial_number": device["serialNumber"],
         }
 
     def delete_device(self, device_id: str):
@@ -462,11 +460,11 @@ class Client:
 
         :param device_id: The id of the device.
         """
-        request = requests.delete(
+        response = requests.delete(
             self.__url__(f"/v1/devices/{device_id}"),
             headers=self.__headers,
         )
-        request.raise_for_status()
+        json_or_raise(response)
 
     def delete_import(self, device_id: str, import_id: str):
         """
@@ -475,12 +473,12 @@ class Client:
         :param device_id: The id of the device associated with the import.
         :param import_id: The id of the import to delete.
         """
-        request = requests.delete(
+        response = requests.delete(
             self.__url__(f"/v1/data/imports/{import_id}"),
             params={"deviceId": device_id},
             headers=self.__headers,
         )
-        request.raise_for_status()
+        json_or_raise(response)
 
     def get_imports(
         self,
@@ -491,6 +489,10 @@ class Client:
         data_end: Optional[datetime.datetime] = None,
         include_deleted: bool = False,
         filename: Optional[str] = None,
+        sort_by: Optional[str] = None,
+        sort_order: Optional[str] = None,
+        limit: Optional[int] = None,
+        offset: Optional[int] = None,
     ):
         """
         Fetches imports.
@@ -502,6 +504,10 @@ class Client:
         :param data_end: Optionally filter by data end time.
         :param include_deleted: Include deleted imports.
         :param filename: Optionally filter by matching filename.
+        :param sort_by: Optionally sort records by this field name (e.g. "device_id").
+        :param sort_order: Optionally specify the sort order, either "asc" or "desc".
+        :param limit: Optionally limit the number of records returned.
+        :param offset: Optionally offset the results by this many records.
         """
         all_params = {
             "deviceId": device_id,
@@ -511,10 +517,14 @@ class Client:
             "dataEnd": data_end.astimezone().isoformat() if data_end else None,
             "includeDeleted": include_deleted,
             "filename": filename,
+            "sortBy": camelize(sort_by),
+            "sortOrder": sort_order,
+            "limit": limit,
+            "offset": offset,
         }
         response = requests.get(
             self.__url__("/v1/data/imports"),
-            params={k: v for k, v in all_params.items() if v},
+            params={k: v for k, v in all_params.items() if v is not None},
             headers=self.__headers,
         )
         json = json_or_raise(response)
