@@ -13,19 +13,17 @@ fake = Faker()
 def test_create_device():
     id = fake.uuid4()
     name = "name"
-    serial_number = "serial"
     responses.add(
         responses.POST,
         api_url("/v1/devices"),
         json={
             "id": id,
             "name": name,
-            "serialNumber": serial_number,
         },
     )
     client = Client("test")
-    device = client.create_device(name=name, serial_number=serial_number)
-    assert device["serial_number"] == serial_number
+    device = client.create_device(name=name)
+    assert device["name"] == name
 
 
 @responses.activate
@@ -37,7 +35,6 @@ def test_get_device():
         json={
             "id": id,
             "name": fake.sentence(2),
-            "serialNumber": fake.pyint(),
             "createdAt": datetime.now().isoformat(),
             "updatedAt": datetime.now().isoformat(),
         },
@@ -57,7 +54,6 @@ def test_get_devices():
             {
                 "id": id,
                 "name": fake.sentence(2),
-                "serialNumber": fake.pyint(),
                 "createdAt": datetime.now().isoformat(),
                 "updatedAt": datetime.now().isoformat(),
             }
@@ -72,8 +68,6 @@ def test_get_devices():
 @responses.activate
 def test_delete_device():
     id = fake.uuid4()
-    name = "name"
-    serial_number = "serial"
     responses.add(
         responses.DELETE,
         api_url(f"/v1/devices/{id}"),
